==> lrabbit_scrapy-2.0.0.tar.gz: lrabbit_scrapy-2.0.0/src/lrabbit_scrapy/common_utils/network_helper.py <==
# -*- coding: utf-8 -*-
"""
@Time    : 2021/11/18 10:21
@Author  : lrabbit
@FileName: network_helper.py
@Software: PyCharm
@Blog    : https://www.lrabbit.life
"""

import copy
import urllib3
import requests
from lrabbit_scrapy.all_excepiton import Excepiton403, Excepiton404, Excepiton500

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class RequestSession:

    def __init__(self, proxies=None, timeout=9):
        self.proxies = proxies
        self.timeout = timeout
        self.session = requests.session()

    def send_request(self, method='GET', url=None, headers=None, data=None):
        if headers:
            headers = copy.copy(self.session.headers).update(headers)
        if method == 'GET':
            res = self.session.get(url, proxies=self.proxies, verify=False, timeout=self.timeout)
        else:
            if isinstance(data, dict):
                res = self.session.post(url, json=data, proxies=self.proxies, headers=headers, verify=False,
                                        timeout=self.timeout)
            elif isinstance(data, str):
                res = self.session.get(url, data=data, proxies=self.proxies, headers=headers, verify=False,
                                       timeout=self.timeout)
            else:
                print("未提交参数")
        return self.deal_res(res)

    def download_file_by_url(self, out_file_path, url, headers=None):
        res = self.session.post(url=url, headers=headers, proxies=self.proxies)
        with open(out_file_path, 'wb') as f:
            for chunk in res.iter_content(1024):
                if chunk:
                    f.write(chunk)
        return out_file_path

    def deal_res(self, res):
        if res.status_code == 403:
            raise Excepiton403()
        elif res.status_code == 404:
            raise Excepiton404()
        elif res.status_code == 500:
            raise Excepiton500()
        return res.text


if __name__ == '__main__':
    session = RequestSession()

==> lrabbit_scrapy-2.0.1.tar.gz: lrabbit_scrapy-2.0.1/src/lrabbit_scrapy/common_utils/network_helper.py <==
# -*- coding: utf-8 -*-
"""
@Time    : 2021/11/18 10:21
@Author  : lrabbit
@FileName: network_helper.py
@Software: PyCharm
@Blog    : https://www.lrabbit.life
"""

import urllib3
import requests
from lrabbit_scrapy.all_excepiton import Excepiton403, Exception404, Exception500

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)


class RequestSession:

    def __init__(self, proxies=None, timeout=9, headers=None):
        self.proxies = proxies
        self.timeout = timeout
        self.session = requests.session()
        self.session.headers = headers

    def send_request(self, method='GET', url=None, headers=None, data=None):

        if method == 'GET':
            res = self.session.get(url, proxies=self.proxies, verify=False, timeout=self.timeout)
        else:
            if isinstance(data, dict):
                res = self.session.post(url, json=data, proxies=self.proxies, headers=headers, verify=False,
                                        timeout=self.timeout)
            elif isinstance(data, str):
                res = self.session.get(url, data=data, proxies=self.proxies, headers=headers, verify=False,
                                       timeout=self.timeout)
            else:
                print("未提交参数")
        return self.deal_res(res)

    def download_file_by_url(self, out_file_path, url, headers=None):
        res = self.session.post(url=url, headers=headers, proxies=self.proxies, verify=False, stream=True,
                                timeout=self.timeout)
        with open(out_file_path, 'wb') as f:
            for chunk in res.iter_content(1024):
                if chunk:
                    f.write(chunk)
        return out_file_path

    def deal_res(self, res):
        if res.status_code == 403:
            raise Excepiton403()
        elif res.status_code == 404:
            raise Exception404()
        elif res.status_code == 500:
            raise Exception500()
        return res.text


if __name__ == '__main__':
    session = RequestSession()
